@@ -1,22 +1,24 @@
-( cd usr/X11R7/lib ; rm -rf libglut.so.3 )
-( cd usr/X11R7/lib ; ln -sf libglut.so.3.7.1 libglut.so.3 )
-( cd usr/X11R7/lib ; rm -rf libGLU.so )
-( cd usr/X11R7/lib ; ln -sf libGLU.so.1 libGLU.so )
 ( cd usr/X11R7/lib ; rm -rf libGL.so )
 ( cd usr/X11R7/lib ; ln -sf libGL.so.1 libGL.so )
-( cd usr/X11R7/lib ; rm -rf libGLU.so.1 )
-( cd usr/X11R7/lib ; ln -sf libGLU.so.1.3.070700 libGLU.so.1 )
-( cd usr/X11R7/lib ; rm -rf libEGL.so )
-( cd usr/X11R7/lib ; ln -sf libEGL.so.1 libEGL.so )
-( cd usr/X11R7/lib ; rm -rf libglut.so )
-( cd usr/X11R7/lib ; ln -sf libglut.so.3 libglut.so )
 ( cd usr/X11R7/lib ; rm -rf libGL.so.1 )
 ( cd usr/X11R7/lib ; ln -sf libGL.so.1.2 libGL.so.1 )
+( cd usr/X11R7/lib ; rm -rf libOSMesa.so )
+( cd usr/X11R7/lib ; ln -sf libOSMesa.so.7 libOSMesa.so )
+( cd usr/X11R7/lib ; rm -rf libOSMesa.so.7 )
+( cd usr/X11R7/lib ; ln -sf libOSMesa.so.7.8.2 libOSMesa.so.7 )
+( cd usr/X11R7/lib ; rm -rf libEGL.so )
+( cd usr/X11R7/lib ; ln -sf libEGL.so.1 libEGL.so )
 ( cd usr/X11R7/lib ; rm -rf libEGL.so.1 )
 ( cd usr/X11R7/lib ; ln -sf libEGL.so.1.0 libEGL.so.1 )
+( cd usr/X11R7/lib ; rm -rf libGLU.so )
+( cd usr/X11R7/lib ; ln -sf libGLU.so.1 libGLU.so )
+( cd usr/X11R7/lib ; rm -rf libGLU.so.1 )
+( cd usr/X11R7/lib ; ln -sf libGLU.so.1.3.070802 libGLU.so.1 )
 ( cd usr/X11R7/lib ; rm -rf libGLw.so )
 ( cd usr/X11R7/lib ; ln -sf libGLw.so.1 libGLw.so )
 ( cd usr/X11R7/lib ; rm -rf libGLw.so.1 )
 ( cd usr/X11R7/lib ; ln -sf libGLw.so.1.0.0 libGLw.so.1 )
-( cd usr/include ; rm -rf GL )
-( cd usr/include ; ln -sf ../X11R7/include/GL GL )
+( cd usr/X11R7/lib ; rm -rf libglut.so )
+( cd usr/X11R7/lib ; ln -sf libglut.so.3 libglut.so )
+( cd usr/X11R7/lib ; rm -rf libglut.so.3 )
+( cd usr/X11R7/lib ; ln -sf libglut.so.3.7.1 libglut.so.3 )
